Learn R Programming

rstatscn (version 1.0.2)

statscnRegions: the regions in db

Description

the available regions in the specified db, it is used for query the province, city and country code generally

Usage

statscnRegions(dbcode = "fsnd")

Arguments

dbcode
the dbcode should be some province db(fs*) , city db(cs*) or internaltional db(gj*)

Value

the data frame with all the available region codes and names in the db

Examples

Run this code
 statscnRegions('fsnd')
 statscnRegions('csnd')
 statscnRegions('gjnd')

Run the code above in your browser using DataLab